/*
  // TCS230 color recognition with calibration
  modified on 7 May 2019
  by Mohammadreza Akbari @ Electropeak
  https://electropeak.com/learn/

  Color Sensor      Arduino
  -----------      --------
  VCC               5V
  GND               GND
  s0                8
  s1                9
  s2                10
  s3                11
  OUT               12
  OE                GND
*/
#include <Wire.h>
#include <LiquidCrystal_I2C.h>
LiquidCrystal_I2C lcd_I2C_27(0x27,16,2);

const int s0 = 3;
const int s1 = 2;
const int s2 = 9;
const int s3 = 10;
const int out = 8;
// LED pins connected to Arduino
int redLed = 5;
int greenLed = 6;
int blueLed = 3;
// Variables
int red = 0;
int green = 0;
int blue = 0;

// Calibrated value
int cal_min = 5;
int cal_max_r = 50;
int cal_max_g = 50;
int cal_max_b = 50;

void calibrate() {
  Serial.println("Clear sensor area. Then enter c again");
    while (Serial.read() != 'c') {
      //do nothing
      ;
    }
    color();
    cal_max_r = red;
    cal_max_g = green;
    cal_max_b = blue;
    Serial.println("Put white color infront of sensor, Then enter c again");
    while (Serial.read() != 'c') {
      //do nothing
      ;
    }
    color();
    cal_min = (red + green + blue) / 3;
    Serial.println("calibrated successfully.");
    delay(300);
}

void color() {
  digitalWrite(s2, LOW);
  digitalWrite(s3, LOW);
  //count OUT, pRed, RED
  red = pulseIn(out, digitalRead(out) == HIGH ? LOW : HIGH);
  digitalWrite(s3, HIGH);
  //count OUT, pBLUE, BLUE
  blue = pulseIn(out, digitalRead(out) == HIGH ? LOW : HIGH);
  digitalWrite(s2, HIGH);
  //count OUT, pGreen, GREEN
  green = pulseIn(out, digitalRead(out) == HIGH ? LOW : HIGH);
}
void speech1(){
  unsigned char i = 0;
  unsigned char head[16];

  head[0] = 0xFD;
  head[1] = 0x00;
  head[2] = 0x0D;
  head[3] = 0x01;
  head[4] = 0x00;
  head[5] = 0xBA;
  head[6] = 0xEC;
  head[7] = 0xB5;
  head[8] = 0xC6;
  head[9] = 0xC7;
  head[10] = 0xEB;
  head[11] = 0xD6;
  head[12] = 0xB9;
  head[13] = 0xB2;
  head[14] = 0xBD;
  head[15] = 0x98;

  for(i=0; i<16; i++){
    Serial.write(head[i]);
  }
}
void speech2(){
  unsigned char i = 0;
  unsigned char head[16];

  head[0] = 0xFD;
  head[1] = 0x00;
  head[2] = 0x0D;
  head[3] = 0x01;
  head[4] = 0x00;
  head[5] = 0xC2;
  head[6] = 0xCC;
  head[7] = 0xB5;
  head[8] = 0xC6;
  head[9] = 0xC7;
  head[10] = 0xEB;
  head[11] = 0xC7;
  head[12] = 0xB0;
  head[13] = 0xD0;
  head[14] = 0xD0;
  head[15] = 0xD7;

  for(i=0; i<16; i++){
    Serial.write(head[i]);
  }
}



void setup()
{
  Serial.begin(9600);
  pinMode(4,OUTPUT);
  pinMode(s0, OUTPUT);
  pinMode(s1, OUTPUT);
  pinMode(s2, OUTPUT);
  pinMode(s3, OUTPUT);
  pinMode(out, INPUT);
  pinMode(redLed, OUTPUT);
  pinMode(greenLed, OUTPUT);
  pinMode(blueLed, OUTPUT);
  digitalWrite(s0, HIGH);
  digitalWrite(s1, HIGH);
  digitalWrite(4,HIGH);
  lcd_I2C_27.init (); // initialize the lcd
  lcd_I2C_27.backlight();
}

void loop()
{
  color();
  if (Serial.read() == 'c') {
    calibrate();
  }


  red = map(red, cal_min, cal_max_r, 255, 0);
  green = map(green, cal_min, cal_max_g, 255, 0);
  blue = map(blue, cal_min, cal_max_b, 255, 0);
  Serial.print("R Intensity:");
  Serial.print(red);
  Serial.print(" G Intensity: ");
  Serial.print(green);
  Serial.print(" B Intensity : ");
  Serial.println(blue);
  delay(200);
   if(red>green+10&&red>150){
    
  lcd_I2C_27.setCursor(0 , 0) ;
  lcd_I2C_27.clear();
  lcd_I2C_27.println("Red Attention");
  
  speech1();
  delay(3000);
  
  
  
  
   }else{lcd_I2C_27.setCursor(0 , 0) ;
   lcd_I2C_27.clear();
  lcd_I2C_27.println("Green Go");
  delay(500);
  speech2();
  delay(3000);
  
  
    }
}
